//===================================CISCKER====================================
//------------------------------------------------------------------------------
//File Name:	CISCKER.v
//Purpose:		Instantiation of CISCKER processor
//Parameters:	None
//------------------------------------------------------------------------------
//=====================Alfredo Gualdron - Jose P. Pinilla=======================
//=================================Semillero ADT================================
//================================UPB Bucaramanga===============================
//Website:	http://semilleroadt.upbbga.edu.co/xiscker
//E-mail:	semilleroadt@gmail.com
//------------------------------------------------------------------------------

`timescale 1ns / 1ps

module CISCKER 
	#(
	parameter clk_limit=100000
	)(
	input clk_50M,
	input [1:0]PButton,
	input [3:0]SW,
	output [7:0]port
	);
//=====================Clock Frequency==========================
	
wire div_clk;

Generate_Arbitrary_Divided_Clk32 clk_div(
	.inclk(clk_50M),
	.outclk(div_clk),
	.div_clk_count(clk_limit)
	);

//================Clocks Phase Shift=================

//With this signal the processors clocks can be stopped for stand-by functions.
wire stop = 0;
	
reg clk_rst = 1;
always @ (posedge div_clk)
	clk_rst <= stop;

phaser phased_clks (
	.clk_in(div_clk),
	.reset(clk_rst),
	.clk_270(clk_270),
	.clk_180(clk_180),
	.clk_90(clk_90),
	.clk_0(clk_0)
    );

//===============Initial State and Reset=============

reg load = 1;
always @ (posedge clk_90)
	if(PButton[0])
		load <= 0;
	else
		load <= 1;

//======================Processor====================
//Temporary Outputs, configure according to your design
wire [7:0]out_temp;
wire [7:0]out_temp1;
wire [7:0]out_temp2;
		
datapath datapath_ciscker (
    .clk_0(clk_0), 
    .clk_90(clk_90), 
    .clk_180(clk_180), 
    .clk_270(clk_270), 
    .load(load),
	 .input_port1({4'b0,SW}),
	 .input_port2({4'b0,SW}),
	 .output_port1(out_temp1),
	 .output_port2(out_temp2)
    );

//================External Assignments===============

assign port = SW[0] ? out_temp : SW[1] ? out_temp1 : out_temp2;

endmodule 